//////////////////////////////////////////////////
////////////A simple Box Blur Shader//////////////
//////////////////////////////////////////////////
//////////////////////////////////////////////////
////14.01.2008////////////////by Nils Daumann/////
/////////////slindev.wordpress.com////////////////
//////////////////////////////////////////////////

Texture TargetMap;
float4 vecSkill1; //x = blur radius
sampler boxMapSampler = sampler_state
{
	texture = <TargetMap>;
	mipfilter = LINEAR;
};
float4 vecViewPort;

//Box Blur
const float4 samples[4] =
{
   -1.0,  0.0, 0, 0.25,
    1.0,  0.0, 0, 0.25,
    0.0,  1.0, 0, 0.25,
    0.0, -1.0, 0, 0.25
};

float4 ps_main(float2 TexCoord : TEXCOORD0) : COLOR0
{
   float4 Color = 0;
   
   // Sample and output the box averaged colors
   for(int i=0; i<4; i++)
      Color += samples[i].w*tex2D(boxMapSampler,TexCoord+float2(samples[i].x*vecViewPort.z,samples[i].y*vecViewPort.w));
   
   //return tex2D(boxMapSampler,TexCoord);
   return Color;
}


#define NUM_TAPS 12

static const float2 fTaps_Poisson[NUM_TAPS] = {
	{-.326,-.406},
	{-.840,-.074},
	{-.696, .457},
	{-.203, .621},
	{ .962,-.195},
	{ .473,-.480},
	{ .519, .767},
	{ .185,-.893},
	{ .507, .064},
	{ .896, .412},
	{-.322,-.933},
	{-.792,-.598}};

// Poisson blur pixel shader
float4 PoissonPS (in float2 inShadow: TEXCOORD0) : COLOR0
{
	float4 fShadow = float4(0.0,0.0,0.0,0.0);
	for (int i=0; i < NUM_TAPS; i++)
	{
		fShadow.rgba += tex2D(boxMapSampler,inShadow + fTaps_Poisson[i]*vecSkill1.x*vecViewPort.zw);
	}
	fShadow *= 1.0/NUM_TAPS;
	return fShadow;
	//float4 org = tex2D(boxMapSampler,inShadow);
	//return float4(fShadow.r,org.g,org.b,fShadow.a);
}

technique Main
{
	pass RenderShadowMap
	{
		PixelShader = compile ps_2_0 PoissonPS();
		//PixelShader = compile ps_2_0 ps_main();
	}
}